@@ -3,7 +3,7 @@ import socket
 from datetime import datetime, timedelta
 from ipaddress import ip_address
 from pathlib import Path
-import warnings
+from typing import Union
 
 from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
@@ -15,7 +15,10 @@ from cryptography.x509.oid import NameOID
 log = logging.getLogger(__name__)
 
 
-def _generate_certs(path, days=3652, key_size=2048, separate_key=False):
+def _generate_certs(path: Union[Path, str],
+                    days: int = 3652,
+                    key_size: int = 2048,
+                    separate_key: bool = False) -> None:
     # DO NOT USE THIS FOR ANYTHING PRODUCTION RELATED, EVER!
     # Generate private key
     # 2048 is the minimum that works as of 3.9
@@ -32,7 +35,6 @@ def _generate_certs(path, days=3652, key_size=2048, separate_key=False):
 
     # Generate public certificate
     hostname = socket.gethostname()
-    ip = socket.gethostbyname(hostname)
     subject = Name([NameAttribute(NameOID.COMMON_NAME, "smtpdfix_cert")])
     alt_names = [
         DNSName("localhost"),
@@ -41,8 +43,18 @@ def _generate_certs(path, days=3652, key_size=2048, separate_key=False):
         IPAddress(ip_address("127.0.0.1")),
         IPAddress(ip_address("0.0.0.1")),
         IPAddress(ip_address("::1")),
-        IPAddress(ip_address(ip)),
     ]
+
+    # Because on misconfigured systems it's possible to have a hostname that
+    # doesn't resolve to an IP we catch the error and skip adding it to the
+    # list of altnames. (issue #195)
+    try:
+        ip = socket.gethostbyname(hostname)
+        alt_names.append(IPAddress(ip_address(ip)))
+    except socket.gaierror as err:
+        log.info(f"{hostname} failed to resolve to ip")
+        log.error(err.strerror)
+
     # Set it so the certificate can be a root certificate with
     # ca=true, path_length=0 means it can only sign itself.
     constraints = BasicConstraints(ca=True, path_length=0)
@@ -62,11 +74,3 @@ def _generate_certs(path, days=3652, key_size=2048, separate_key=False):
     with open(cert_path, "ab") as f:
         f.write(cert.public_bytes(serialization.Encoding.PEM))
     log.debug("Certificate generated")
-
-
-def generate_certs(path, days=3652, key_size=2048, separate_key=False):
-    _message = ("_generate_certs will be removed from the public API as of ",
-                "version 0.4.")
-    warnings.warn(_message, PendingDeprecationWarning)
-
-    return _generate_certs(path, days, key_size, separate_key)
