@@ -1,5 +1,6 @@
 import logging
 import os
+from typing import Any, Generator, Optional
 
 import pytest
 
@@ -7,36 +8,43 @@ from .authenticator import Authenticator
 from .certs import _generate_certs
 from .configuration import Config
 from .controller import AuthController
+from .typing import TempPathFactory
 
 log = logging.getLogger(__name__)
 
 
 class _Authenticator(Authenticator):
-    def __init__(self, config):
+    def __init__(self, config: Config) -> None:
         self.config = config
 
-    def validate(self, username, password):
+    def validate(self, username: str, password: str) -> bool:
         if (
-            username == self.config.login_username and
-            password == self.config.login_password
+            username == self.config.login_username
+            and password == self.config.login_password
         ):
-            log.debug(("Validating username and password for succeeded"))
+            log.debug("Validating username and password for succeeded")
             return True
 
         log.debug("Validating username and password failed")
         return False
 
-    def get_password(self, username):
+    def verify(self, username: str) -> bool:
+        return super().verify(username)
+
+    def get_password(self, username: Optional[str]) -> str:
         return self.config.login_password
 
 
 class SMTPDFix():
-    def __init__(self, hostname=None, port=8025, config=None):
+    def __init__(self,
+                 hostname: Optional[str] = None,
+                 port: int = 8025,
+                 config: Optional[Config] = None) -> None:
         self.hostname = hostname
         self.port = int(port) if port is not None else 8025
         self.config = config or Config()
 
-    def __enter__(self):
+    def __enter__(self) -> AuthController:
         self.controller = AuthController(
             hostname=self.hostname,
             port=self.port,
@@ -46,12 +54,14 @@ class SMTPDFix():
         self.controller.start()
         return self.controller
 
-    def __exit__(self, type, value, traceback):
+    def __exit__(self, type: Any, value: Any, traceback: Any) -> None:
         self.controller.stop()
 
 
 @pytest.fixture
-def smtpd(tmp_path_factory):
+def smtpd(
+    tmp_path_factory: TempPathFactory
+) -> Generator[AuthController, None, None]:
     """A small SMTP server for use when testing applications that send email
     messages. To access the messages call `smtpd.messages` which returns a copy
     of the list of messages sent to the server.
